# Mulai!

Selamat datang di Rapunzel, lingkungan pengembangan modern untuk Python dan R. Berikut adalah beberapa pintasan keyboard yang berguna.


## Bekerja dengan folder dan file proyek

- [`Ctrl+Shift+O`: Buka folder proyek](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Buka file dari folder proyek](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Buat dokumen kosong](opensesame://event.ide_new_file)


## Melakukan hal dengan cepat

- [`Ctrl+Shift+P`: Aktifkan palet perintah](opensesame://event.command_palette_activate)
- `Ctrl+R`: Lompat ke fungsi atau kelas


## Menjalankan kode

- `F5`: Jalankan proyek atau file
- `F9`: Jalankan seleksi, sel, atau baris saat ini